BPA Audible Noise
========================

The following are the AC and DC audible noise empirical formula developed by
the Bonneville Power Administration (BPA).

AC
**

Constants:

.. image:: helpdocs/equations/bpa_ac_constants.png

Generated acoustic power:

.. image:: helpdocs/equations/bpa_ac_gap.png

Sound pressure level:

.. image:: helpdocs/equations/bpa_ac_spl_50.png

Total sound pressure level from all phases:

.. image:: helpdocs/equations/spl_sum.png

Fair weather correction factor:

.. image:: helpdocs/equations/bpa_ac_fair_corr.png

DC
**

Equivalent conductor diameter:

.. image:: helpdocs/equations/bpa_dc_d_eq.png

Generated acoustic power:

.. image:: helpdocs/equations/bpa_dc_gap.png

Sound pressure level:

.. image:: helpdocs/equations/bpa_dc_spl_50.png

Total sound pressure level from all phases:

.. image:: helpdocs/equations/spl_sum.png

Foul weather correction factor:

.. image:: helpdocs/equations/bpa_dc_foul_corr.png

Seasonal correction factor:

.. image:: helpdocs/equations/bpa_dc_summer_corr.png
.. image:: helpdocs/equations/bpa_dc_winter_corr.png
